==> scraping-1.1.8-sources.jar: com/tenqube/visual_scraper/model/jsonParsing/MallScrapInfo.java <==
package com.tenqube.visual_scraper.model.jsonParsing;

import com.tenqube.visual_scraper.db.entity.newEntity.LoginApiRule;
import com.tenqube.visual_scraper.db.entity.newEntity.LoginWebRule;
import com.tenqube.visual_scraper.db.entity.newEntity.MallEntity;
import com.tenqube.visual_scraper.db.entity.newEntity.OrderApiRuleJson;
import com.tenqube.visual_scraper.db.entity.newEntity.OrderWebRuleJson;

import java.io.Serializable;
import java.util.List;

public class MallScrapInfo implements Serializable {

    private int version;
    private List<MallEntity> malls;
    private List<LoginWebRule> loginHtmlRules;
    private List<LoginApiRule> loginJsonRules;
    private List<OrderWebRuleJson> orderHtmlRules;
    private List<OrderApiRuleJson> orderJsonRules;

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public List<MallEntity> getMalls() {
        return malls;
    }

    public void setMalls(List<MallEntity> malls) {
        this.malls = malls;
    }

    public List<LoginWebRule> getLoginHtmlRules() {
        return loginHtmlRules;
    }

    public void setLoginHtmlRules(List<LoginWebRule> loginHtmlRules) {
        this.loginHtmlRules = loginHtmlRules;
    }

    public List<LoginApiRule> getLoginJsonRules() {
        return loginJsonRules;
    }

    public void setLoginJsonRules(List<LoginApiRule> loginJsonRules) {
        this.loginJsonRules = loginJsonRules;
    }

    public List<OrderWebRuleJson> getOrderHtmlRules() {
        return orderHtmlRules;
    }

    public void setOrderHtmlRules(List<OrderWebRuleJson> orderHtmlRules) {
        this.orderHtmlRules = orderHtmlRules;
    }

    public List<OrderApiRuleJson> getOrderJsonRules() {
        return orderJsonRules;
    }

    public void setOrderJsonRules(List<OrderApiRuleJson> orderJsonRules) {
        this.orderJsonRules = orderJsonRules;
    }

    @Override
    public String toString() {
        return "MallScrapInfo{" +
                "version=" + version +
                ", malls=" + malls +
                ", loginHtmlRules=" + loginHtmlRules +
                ", loginJsonRules=" + loginJsonRules +
                ", orderHtmlRules=" + orderHtmlRules +
                ", orderJsonRules=" + orderJsonRules +
                '}';
    }
}

==> scraping-1.1.17-sources.jar: com/tenqube/visual_scraper/model/jsonParsing/MallScrapInfo.java <==
package com.tenqube.visual_scraper.model.jsonParsing;

import com.tenqube.visual_scraper.db.entity.newEntity.LoginApiRule;
import com.tenqube.visual_scraper.db.entity.newEntity.LoginWebRule;
import com.tenqube.visual_scraper.db.entity.newEntity.MallEntity;
import com.tenqube.visual_scraper.db.entity.newEntity.OrderApiRuleJson;
import com.tenqube.visual_scraper.db.entity.newEntity.OrderDetailWebRule;
import com.tenqube.visual_scraper.db.entity.newEntity.OrderWebRuleJson;

import java.io.Serializable;
import java.util.List;

public class MallScrapInfo implements Serializable {

    private int version;
    private List<MallEntity> malls;
    private List<LoginWebRule> loginHtmlRules;
    private List<LoginApiRule> loginJsonRules;
    private List<OrderWebRuleJson> orderHtmlRules;
    private List<OrderApiRuleJson> orderJsonRules;
    private List<OrderDetailWebRule> orderDetailHtmlRules;


    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public List<MallEntity> getMalls() {
        return malls;
    }

    public void setMalls(List<MallEntity> malls) {
        this.malls = malls;
    }

    public List<LoginWebRule> getLoginHtmlRules() {
        return loginHtmlRules;
    }

    public void setLoginHtmlRules(List<LoginWebRule> loginHtmlRules) {
        this.loginHtmlRules = loginHtmlRules;
    }

    public List<LoginApiRule> getLoginJsonRules() {
        return loginJsonRules;
    }

    public void setLoginJsonRules(List<LoginApiRule> loginJsonRules) {
        this.loginJsonRules = loginJsonRules;
    }

    public List<OrderWebRuleJson> getOrderHtmlRules() {
        return orderHtmlRules;
    }

    public void setOrderHtmlRules(List<OrderWebRuleJson> orderHtmlRules) {
        this.orderHtmlRules = orderHtmlRules;
    }

    public List<OrderApiRuleJson> getOrderJsonRules() {
        return orderJsonRules;
    }

    public void setOrderJsonRules(List<OrderApiRuleJson> orderJsonRules) {
        this.orderJsonRules = orderJsonRules;
    }

    public List<OrderDetailWebRule> getOrderDetailHtmlRules() {
        return orderDetailHtmlRules;
    }

    public void setOrderDetailHtmlRules(List<OrderDetailWebRule> orderDetailHtmlRules) {
        this.orderDetailHtmlRules = orderDetailHtmlRules;
    }

    @Override
    public String toString() {
        return "MallScrapInfo{" +
                "version=" + version +
                ", malls=" + malls +
                ", loginHtmlRules=" + loginHtmlRules +
                ", loginJsonRules=" + loginJsonRules +
                ", orderHtmlRules=" + orderHtmlRules +
                ", orderJsonRules=" + orderJsonRules +
                ", orderDetailHtmlRules=" + orderDetailHtmlRules +
                '}';
    }
}
